API docs for “spamfighter.core.message.attribute.Attribute”

# Class s.c.m.a.Attribute(object):

Part of spamfighter.core.message.attribute View Source View In Hierarchy

Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.

Атрибут является частью сообщения (`IMessage`), тип атрибута (`IAttributeDomain`) - его свойством.

Instance Variables | _domain | домен атрибута (type: `IAttributeDomain` )
| _value | значение атрибута

Method | __init__ | Конструктор.
Method | domain | Получить домен атрибута.
Method | value | Получить значение атрибута.
Method | serialize | Получить сериализованное значение атрибута.
Method | __eq__ | Undocumented
Method | __repr__ | Undocumented

def __init__(self, domain, value): (source)
Конструктор.

Parameters | domain | (type: `IAttributeDomain` )
Instance Variables | domain | домен атрибута
| value | значение атрибута

def domain(self): (source)
Получить домен атрибута.

Returns | домен атрибута (type: `IAttributeDomain` )

def value(self): (source)
Получить значение атрибута.

Returns | значение атрибута

def serialize(self): (source)
Получить сериализованное значение атрибута.

Returns | сериализованное значение атрибута

def __eq__(self, other): (source)
Undocumented
def __repr__(self): (source)
Undocumented